module Procedures::Restore
  class RegenerateMissingQueues < ForemanMaintain::Procedure
    
    metadata do
      description 'Regenrate queues'

      param :handle_services,
            'Stop and start services if required',
            :flag => true,
            :default => false
    end

    def hostname
      execute('hostname -f')
    end

    def ssl_cert
      "/etc/pki/katello/certs/#{hostanme}-qpid-broker.crt"
    end

    def ssl_key
      "/etc/pki/katello/private/#{hostanme}-qpid-broker.key"
    end

    def amqps_url
      'amqps://localhost:5671'
    end

    def run
      with_spinner('Resetting the queues') do |spinner|
        reset_queues
      end
    end

    def reset_queues      
      execute!('rm -rf /var/lib/qpidd/.qpidd/qls')
      Procedures::Service::Start(:only => 'qpidd')
      puts "Sleeping for 60 seconds for qpid to start fully"
      sleep 60

      puts "Recreating infrastructure queues.."
      execute!("qpid-config --ssl-certificate #{ssl_cert} --ssl-key #{ssl_key} -b #{amqps_url} add exchange topic event --durable")
      execute!("qpid-config --ssl-certificate #{ssl_cert} --ssl-key #{ssl_key} -b #{amqps_url} add queue katello_event_queue --durable")
      %w[compliance.created entitlement.created entitlement.deleted pool.created pool.deleted].each do |key|
      execute!("qpid-config --ssl-certificate #{ssl_cert} --ssl-key #{ssl_key} -b #{amqps_url} bind event katello_event_queue #{key}")
    end



    end
  end
end
